@@ -20,11 +20,11 @@
 #  lines,timeSeries          Adds lines to a 'timeSeries' plot
 #  points,timeSeries         Adds points to a 'timeSeries' plot
 # FUNCTION:                 DESCRIPTION:
-#  pretty.timeSeries         Returns a sequence of equally spaced round values 
+#  pretty.timeSeries         Returns a sequence of equally spaced round values
 ################################################################################
 
 
-.plot.timeSeries <- 
+.plot.timeSeries <-
     function(x, y, FinCenter = NULL,
     plot.type = c("multiple", "single"),
     format = "auto", at = pretty(x),
@@ -57,8 +57,22 @@
 
     # FUNCTION:
 
-    # Check Missing
+    # Check Missing:
     if (missing(y)) y <- NULL
+      
+    # Check for "pretty' and "chic":
+    if (is.character(at)) {
+        if (at[1] == "pretty" || at[1] == "chic") {
+          return(.xtplot.timeSeries(
+            x=x, y=y, FinCenter = FinCenter, 
+            plot.type = plot.type,
+            format = format, at = at, 
+            widths = widths, heights = heights,
+            panel = panel, yax.flip = yax.flip,
+            mar.multi = mar.multi, oma.multi = oma.multi, ...)
+            )
+         } 
+    }
 
     # Labels:
     xlabel <- if (!missing(x)) deparse(substitute(x))
@@ -92,7 +106,8 @@ setMethod("plot", "timeSeries",
                            plot.type = plot.type,
                            format = format, at = at,
                            widths = widths, heights = heights,
-                           xy.labels=xy.labels, xy.lines=xy.lines, panel = panel, nc = nc, yax.flip = yax.flip,
+                           xy.labels=xy.labels, xy.lines=xy.lines, 
+                           panel = panel, nc = nc, yax.flip = yax.flip,
                            mar.multi = mar.multi,
                            oma.multi = oma.multi, axes = axes, ...))
 
@@ -105,7 +120,7 @@ plot.timeSeries <- function(x, y, ...) .plot.timeSeries(x, y, ...)
 
 
 .plotTimeSeries <-
-function(x, y = NULL, plot.type = c("multiple", "single"), 
+function(x, y = NULL, plot.type = c("multiple", "single"),
     xy.labels, xy.lines, panel = lines, nc, xlabel, ylabel,
     type = "l", xlim = NULL, ylim = NULL, xlab = "Time", ylab, log = "",
     col = 1:ncol(x), bg = NA, pch = 1:ncol(x), cex = par("cex"),
@@ -123,7 +138,7 @@ function(x, y = NULL, plot.type = c("multiple", "single"),
     #   see 'plot.ts()'.
 
     # FUNCTION:
-    
+
     # Utility Function:
     plot.type <- match.arg(plot.type)
     nser <- NCOL(x)
@@ -355,54 +370,56 @@ setMethod("points", "timeSeries",
 points.timeSeries <- function(x, FinCenter = NULL, ...)
     .points.timeSeries(x, FinCenter = FinCenter, ...)
 
-    
+
 ################################################################################
 
 
-pretty.timeSeries <- 
-    function(x, n = 5, min.n = n%/%3, shrink.sml = 0.75, 
-        high.u.bias = 1.5, u5.bias = 0.5 + 1.5 * high.u.bias, 
-        eps.correct = 0, ...) 
+pretty.timeSeries <-
+    function(x, n = 5, min.n = n%/%3, shrink.sml = 0.75,
+        high.u.bias = 1.5, u5.bias = 0.5 + 1.5 * high.u.bias,
+        eps.correct = 0, ...)
 {
     # A function implemented by Diethelm Wuertz
-    
+
     # Description:
     #    Returns a sequence of equally spaced round values.
-    
+
     # Details:
-    #    Computes a sequence of about n+1 equally spaced round 
-    #    values which cover the range of the values in x. 
-    #    The values are chosen so that they are 1, 2 or 5 times 
+    #    Computes a sequence of about n+1 equally spaced ?round?
+    #    values which cover the range of the values in x.
+    #    The values are chosen so that they are 1, 2 or 5 times
     #    a power of 10.
-    
+
     # Arguments:
     #    x - a timeSeries object from which the time is
     #        extracted
-    #    n - integer giving the desired number of intervals.  
-    #    min.n  - nonnegative integer giving the minimal 
-    #        number of intervals. 
-    #    shrink.sml - positive numeric by a which a default 
-    #        scale is shrunk in the case when range(x) is 
+    #    n - integer giving the desired number of intervals.
+    #    min.n  - nonnegative integer giving the minimal
+    #        number of intervals.
+    #    shrink.sml - positive numeric by a which a default
+    #        scale is shrunk in the case when range(x) is
     #        very small.
-    #    high.u.bias - non-negative numeric, typically > 1. 
+    #    high.u.bias - non-negative numeric, typically > 1.
     #        Larger high.u.bias values favor larger units.
-    #    u5.bias - non-negative numeric multiplier favoring 
+    #    u5.bias - non-negative numeric multiplier favoring
     #        factor 5 over 2.
-    #    eps.correct - integer code, one of {0,1,2}. If 
+    #    eps.correct - integer code, one of {0,1,2}. If
     #       non-0, a correction is made at the boundaries.
     #    ... - further arguments for methods.
-    
+
     # FUNCTION:
-    
-    x <- as.POSIXct(time(x))
-    ans <- pretty(x, n=n, min.n=min.n, shrink.sml=shrink.sml,
-        high.u.bias=high.u.bias, u5.bias=u5.bias, 
-        eps.correct=eps.correct, ...)
-        
-    # Return Value:
-    as.timeDate(ans)
-}   
- 
+
+    td <- time(x)
+    if (inherits(x, "timeDate")) {
+        x <- as.POSIXct(td)
+        as.timeDate(pretty(x, n=n, min.n=min.n, shrink.sml=shrink.sml,
+                           high.u.bias=high.u.bias, u5.bias=u5.bias,
+                           eps.correct=eps.correct, ...))
+    } else { #-> signal series
+        pretty(td)
+    }
+}
+
 
 ###############################################################################
 
